summaryrefslogtreecommitdiffstats
path: root/libktorrent/interfaces/prefpageinterface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
commit1c1403293485f35fd53db45aaa77a01cdd9627e7 (patch)
tree38559cd68cd4f63023fb5f6375def9db3b8b491e /libktorrent/interfaces/prefpageinterface.h
parent894f94545727610df22c4f73911d62d58266f695 (diff)
downloadktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.tar.gz
ktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.zip
TQt4 port ktorrent
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktorrent@1238733 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libktorrent/interfaces/prefpageinterface.h')
-rw-r--r--libktorrent/interfaces/prefpageinterface.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/libktorrent/interfaces/prefpageinterface.h b/libktorrent/interfaces/prefpageinterface.h
index 7d4d6dc..b27390e 100644
--- a/libktorrent/interfaces/prefpageinterface.h
+++ b/libktorrent/interfaces/prefpageinterface.h
@@ -20,9 +20,9 @@
#ifndef PREFPAGEINTERFACE_H
#define PREFPAGEINTERFACE_H
-#include <qpixmap.h>
+#include <tqpixmap.h>
-class QWidget;
+class TQWidget;
namespace kt
{
@@ -41,12 +41,12 @@ namespace kt
* @param header
* @param pix
*/
- PrefPageInterface(const QString & name,const QString & header,const QPixmap & pix);
+ PrefPageInterface(const TQString & name,const TQString & header,const TQPixmap & pix);
virtual ~PrefPageInterface();
- const QString& getItemName() { return itemName; }
- const QString& getHeader() { return header; }
- const QPixmap& getPixmap() { return pixmap; }
+ const TQString& getItemName() { return itemName; }
+ const TQString& getHeader() { return header; }
+ const TQPixmap& getPixmap() { return pixmap; }
/**
* Apply the changes that have been made in the
@@ -58,9 +58,9 @@ namespace kt
/**
* Create the actual widget.
* @param parent The parent of the widget
*/
- virtual void createWidget(QWidget* parent)=0;
+ virtual void createWidget(TQWidget* tqparent)=0;
/**
* Update all data on the widget, gets called before
@@ -73,11 +73,11 @@ namespace kt
private:
///Used in IconList mode. You should prefer a pixmap with size 32x32 pixels
- QPixmap pixmap;
+ TQPixmap pixmap;
///String used in the list or as tab item name.
- QString itemName;
+ TQString itemName;
///Header text use in the list modes. Ignored in Tabbed mode. If empty, the item text is used instead.
- QString header;
+ TQString header;
};
}
#endif
@@ -58,9 +58,9 @@ namespace kt
/**
* Create the actual widget.
- * @param parent The parent of the widget
+ * @param tqparent The tqparent of the widget
*/